@@ -9,8 +9,13 @@
  * michael@ximian.com
  */
 
-extern int  tile_free             (int);
-extern void generate_game         (guint seed);
+#ifndef SOLUBILITY_H
+#define SOLUBILITY_H
+
+extern int tile_free (int);
+extern void generate_game (guint seed);
 extern void generate_dependencies (void);
 
 int shuffle (void);
+
+#endif /* SOLUBILITY_H */
